==> haskell-tagstream-conduit-0.5.6-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-FAm7EAWYMPDEvUcfaE9C7b
key:                  tagstream-conduit-0.5.6-FAm7EAWYMPDEvUcfaE9C7b
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  2fe72101d047803e171128309d86b7b6
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tagstream-conduit-0.5.6
hs-libraries:         HStagstream-conduit-0.5.6-FAm7EAWYMPDEvUcfaE9C7b
depends:
    attoparsec-0.13.2.4-JZoYjKctPXo3EQxEpGFo7r base-4.14.1.0
    blaze-builder-0.4.1.0-AY5yPUQEaMfQ8f1oQxUHw bytestring-0.10.12.0
    case-insensitive-1.2.1.0-FZs8ch1ucAB4Eu7KUqhUAv
    conduit-1.3.4-AHeP5TUo1kjADD4tHGZdJ3
    conduit-extra-1.3.5-IDX5yGpa0hOJ7VbEVvS7AR
    data-default-0.7.1.1-CIFsAFoYiII7EGHXyyyvlm
    resourcet-1.2.4.2-K5g3mvFPNid6IucH8mdI2c text-1.2.4.1
    transformers-0.5.6.2 xml-conduit-1.9.0.0-BvRf7O640219f2fAAutFnY

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-3dBpXwBrVc7CthEFAKoG9i
key:                  tagstream-conduit-0.5.6-3dBpXwBrVc7CthEFAKoG9i
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  d4d19bb343add7696252a53a89cc95af
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/tagstream-conduit-0.5.6
hs-libraries:         HStagstream-conduit-0.5.6-3dBpXwBrVc7CthEFAKoG9i
depends:
    attoparsec-0.13.2.4-39TJgLEc6zy21miTrRuwax base-4.14.1.0
    blaze-builder-0.4.1.0-AY5yPUQEaMfQ8f1oQxUHw bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L0gITQjreIr3hbLO2ORRC8
    conduit-1.3.4-9kvTHK8uwbp5dGHQvu9pIp
    conduit-extra-1.3.5-IvxJuDyx7Li6YpHr1t0sqg
    data-default-0.7.1.1-Ly8Q7hmVyBgBGNCgPHWDNL
    resourcet-1.2.4.2-LT3ZJbmB51k95TkSus1W04 text-1.2.4.1
    transformers-0.5.6.2 xml-conduit-1.9.0.0-SIDCqO36CALWS8ZKMQl6o

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
